## * Main Functions
##

#### add_sys_path
- environment related

#### read_big_data, read_small_data, save_data, yaml_to_object
- data loading and saving

#### col_to_float, col_to_str
- data reformatting

#### get_sunday, get_time_dif
- deal with time

#### list_diff, list_intersection, list_sym_diff, list_union, set_diff, set_intersection, set_sym_diff, set_union
- the intersection, difference, union of two lists / sets

#### dataframe_mp
- multi-processing

#### calculate_r2_value, lambda_groupby, count_words_in_list
- specials
